@@ -24,8 +24,12 @@ private:
 
     CEvent *event;
 
+    bool saveDefaults;
+
     time_t duration;
 
+    void updateAlarmReference();
+
 private slots:
     void onAllDayChanged(bool enabled);
     void onFromChanged();
