@@ -3,12 +3,13 @@
 
 enum DataRole
 {
-    IdRole = Qt::UserRole,
+    IdRole = Qt::UserRole + 1,
     NameRole,
     TypeRole,
     ColorRole,
     VisibilityRole,
     HeadingRole,
+    DetailsRole,
     DateRole,
     PathRole,
     ComponentRole,
